# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from logit import logit

from support.models import MachineBackInfo, MachineBodyInfo, MachineSupportPrebookInfo
from utils.error.errno_utils import MachineStatusCode
from utils.error.response_utils import response


@logit
def support_info_api(request):
    bodys = MachineBodyInfo.objects.filter(status=True).order_by('position')
    bodys = [body.data for body in bodys]

    backs = MachineBackInfo.objects.filter(status=True).order_by('position')
    backs = [back.data for back in backs]

    return response(200, 'Get Support Info Success', u'获取支持信息成功', {
        'bodys': bodys,
        'backs': backs,
    })


@logit
def support_prebook_submit_api(request):
    user_id = request.POST.get('user_id', '')
    name = request.POST.get('name', '')
    sex = int(request.POST.get('sex', 0))
    phone = request.POST.get('phone', '')
    weekday = int(request.POST.get('weekday', 0))
    timeslice = int(request.POST.get('timeslice', 0))
    body = int(request.POST.get('body', 0))
    back = int(request.POST.get('back', 0))

    try:
        body = MachineBodyInfo.objects.get(pk=body)
    except MachineBodyInfo.DoesNotExist:
        return response(MachineStatusCode.MACHINE_BODY_NOT_FOUND)

    try:
        back = MachineBackInfo.objects.get(pk=back)
    except MachineBackInfo.DoesNotExist:
        return response(MachineStatusCode.MACHINE_BACK_NOT_FOUND)

    MachineSupportPrebookInfo.objects.create(
        user_id=user_id,
        name=name,
        sex=sex,
        phone=phone,
        weekday=weekday,
        timeslice=timeslice,
        body=body,
        back=back,
    )

    return response(200, 'Submit Support Info Success', u'提交支持信息成功')
